@@ -1,39 +1,49 @@
 import enum
 import logging
 from collections import defaultdict
-from typing import Any, Dict
+from typing import Any, Dict, Optional
 
 import click
 
 from .click_common import EnumType, command, format_output
-from .device import Device
+from .device import Device, DeviceStatus
 from .exceptions import DeviceException
 
 _LOGGER = logging.getLogger(__name__)
 
+MODEL_AIRFRESH_A1 = "dmaker.airfresh.a1"
 MODEL_AIRFRESH_T2017 = "dmaker.airfresh.t2017"
 
+AVAILABLE_PROPERTIES_COMMON = [
+    "power",
+    "mode",
+    "pm25",
+    "co2",
+    "temperature_outside",
+    "favourite_speed",
+    "control_speed",
+    "ptc_on",
+    "ptc_status",
+    "child_lock",
+    "sound",
+    "display",
+]
+
 AVAILABLE_PROPERTIES = {
-    MODEL_AIRFRESH_T2017: [
-        "power",
-        "mode",
-        "pm25",
-        "co2",
-        "temperature_outside",
-        "favourite_speed",
-        "control_speed",
+    MODEL_AIRFRESH_T2017: AVAILABLE_PROPERTIES_COMMON
+    + [
         "filter_intermediate",
         "filter_inter_day",
         "filter_efficient",
         "filter_effi_day",
-        "ptc_on",
         "ptc_level",
-        "ptc_status",
-        "child_lock",
-        "sound",
-        "display",
         "screen_direction",
-    ]
+    ],
+    MODEL_AIRFRESH_A1: AVAILABLE_PROPERTIES_COMMON
+    + [
+        "filter_rate",
+        "filter_day",
+    ],
 }
 
 
@@ -60,16 +70,34 @@ class DisplayOrientation(enum.Enum):
     LandscapeRight = "right"
 
 
-class AirFreshStatus:
+class AirFreshStatus(DeviceStatus):
     """Container for status reports from the air fresh t2017."""
 
     def __init__(self, data: Dict[str, Any]) -> None:
         """
-        Response of a Air Airfresh T2017 (dmaker.airfresh.t2017):
+        Response of a Air Fresh A1 (dmaker.airfresh.a1):
+        {
+            'power': True,
+            'mode': 'auto',
+            'pm25': 2,
+            'co2': 554,
+            'temperature_outside': 12,
+            'favourite_speed': 150,
+            'control_speed': 60,
+            'filter_rate': 45,
+            'filter_day': 81,
+            'ptc_on': False,
+            'ptc_status': False,
+            'child_lock': False,
+            'sound': False,
+            'display': False,
+        }
+
+        Response of a Air Fresh T2017 (dmaker.airfresh.t2017):
 
         {
-            'power': true,
-            'mode': "favourite",
+            'power': True,
+            'mode': 'favourite',
             'pm25': 1,
             'co2': 550,
             'temperature_outside': 24,
@@ -79,13 +107,13 @@ class AirFreshStatus:
             'filter_inter_day': 90,
             'filter_efficient': 100,
             'filter_effi_day': 180,
-            'ptc_on': false,
-            'ptc_level': "low",
-            'ptc_status': false,
-            'child_lock': false,
-            'sound': true,
-            'display': false,
-            'screen_direction': "forward",
+            'ptc_on': False,
+            'ptc_level': 'low',
+            'ptc_status': False,
+            'child_lock': False,
+            'sound': True,
+            'display': False,
+            'screen_direction': 'forward',
         }
         """
 
@@ -132,24 +160,24 @@ class AirFreshStatus:
         return self.data["control_speed"]
 
     @property
-    def dust_filter_life_remaining(self) -> int:
+    def dust_filter_life_remaining(self) -> Optional[int]:
         """Remaining dust filter life in percent."""
-        return self.data["filter_intermediate"]
+        return self.data.get("filter_intermediate", self.data.get("filter_rate"))
 
     @property
-    def dust_filter_life_remaining_days(self) -> int:
+    def dust_filter_life_remaining_days(self) -> Optional[int]:
         """Remaining dust filter life in days."""
-        return self.data["filter_inter_day"]
+        return self.data.get("filter_inter_day", self.data.get("filter_day"))
 
     @property
-    def upper_filter_life_remaining(self) -> int:
+    def upper_filter_life_remaining(self) -> Optional[int]:
         """Remaining upper filter life in percent."""
-        return self.data["filter_efficient"]
+        return self.data.get("filter_efficient")
 
     @property
-    def upper_filter_life_remaining_days(self) -> int:
+    def upper_filter_life_remaining_days(self) -> Optional[int]:
         """Remaining upper filter life in days."""
-        return self.data["filter_effi_day"]
+        return self.data.get("filter_effi_day")
 
     @property
     def ptc(self) -> bool:
@@ -157,9 +185,12 @@ class AirFreshStatus:
         return self.data["ptc_on"]
 
     @property
-    def ptc_level(self) -> int:
+    def ptc_level(self) -> Optional[PtcLevel]:
         """PTC level."""
-        return PtcLevel(self.data["ptc_level"])
+        try:
+            return PtcLevel(self.data["ptc_level"])
+        except (KeyError, ValueError):
+            return None
 
     @property
     def ptc_status(self) -> bool:
@@ -182,55 +213,162 @@ class AirFreshStatus:
         return self.data["display"]
 
     @property
-    def display_orientation(self) -> int:
+    def display_orientation(self) -> Optional[DisplayOrientation]:
         """Display orientation."""
-        return DisplayOrientation(self.data["screen_direction"])
+        try:
+            return DisplayOrientation(self.data["screen_direction"])
+        except (KeyError, ValueError):
+            return None
 
-    def __repr__(self) -> str:
-        s = (
-            "<AirFreshStatus power=%s, "
-            "mode=%s, "
-            "pm25=%s, "
-            "co2=%s, "
-            "temperature=%s °C, "
-            "favorite_speed=%s, "
-            "control_speed=%s, "
-            "dust_filter_life_remaining=%s, "
-            "dust_filter_life_remaining_days=%s, "
-            "upper_filter_life_remaining=%s, "
-            "upper_filter_life_remaining_days=%s, "
-            "ptc=%s, "
-            "ptc_level=%s, "
-            "ptc_status=%s, "
-            "child_lock=%s, "
-            "buzzer=%s, "
-            "display=%s, "
-            "display_orientation=%s>"
-            % (
-                self.power,
-                self.mode,
-                self.pm25,
-                self.co2,
-                self.temperature,
-                self.favorite_speed,
-                self.control_speed,
-                self.dust_filter_life_remaining,
-                self.dust_filter_life_remaining_days,
-                self.upper_filter_life_remaining,
-                self.upper_filter_life_remaining_days,
-                self.ptc,
-                self.ptc_level,
-                self.ptc_status,
-                self.child_lock,
-                self.buzzer,
-                self.display,
-                self.display_orientation,
-            )
+
+class AirFreshA1(Device):
+    """Main class representing the air fresh a1."""
+
+    def __init__(
+        self,
+        ip: str = None,
+        token: str = None,
+        start_id: int = 0,
+        debug: int = 0,
+        lazy_discover: bool = True,
+        model: str = MODEL_AIRFRESH_A1,
+    ) -> None:
+        super().__init__(ip, token, start_id, debug, lazy_discover)
+
+        if model in AVAILABLE_PROPERTIES:
+            self.model = model
+        else:
+            self.model = MODEL_AIRFRESH_A1
+
+    @command(
+        default_output=format_output(
+            "",
+            "Power: {result.power}\n"
+            "Mode: {result.mode}\n"
+            "PM2.5: {result.pm25}\n"
+            "CO2: {result.co2}\n"
+            "Temperature: {result.temperature}\n"
+            "Favorite speed: {result.favorite_speed}\n"
+            "Control speed: {result.control_speed}\n"
+            "Dust filter life: {result.dust_filter_life_remaining} %, "
+            "{result.dust_filter_life_remaining_days} days\n"
+            "PTC: {result.ptc}\n"
+            "PTC status: {result.ptc_status}\n"
+            "Child lock: {result.child_lock}\n"
+            "Buzzer: {result.buzzer}\n"
+            "Display: {result.display}\n",
         )
-        return s
+    )
+    def status(self) -> AirFreshStatus:
+        """Retrieve properties."""
+
+        properties = AVAILABLE_PROPERTIES[self.model]
+        values = self.get_properties(properties, max_properties=15)
+
+        return AirFreshStatus(defaultdict(lambda: None, zip(properties, values)))
+
+    @command(default_output=format_output("Powering on"))
+    def on(self):
+        """Power on."""
+        return self.send("set_power", [True])
+
+    @command(default_output=format_output("Powering off"))
+    def off(self):
+        """Power off."""
+        return self.send("set_power", [False])
+
+    @command(
+        click.argument("mode", type=EnumType(OperationMode)),
+        default_output=format_output("Setting mode to '{mode.value}'"),
+    )
+    def set_mode(self, mode: OperationMode):
+        """Set mode."""
+        return self.send("set_mode", [mode.value])
+
+    @command(
+        click.argument("display", type=bool),
+        default_output=format_output(
+            lambda led: "Turning on display" if led else "Turning off display"
+        ),
+    )
+    def set_display(self, display: bool):
+        """Turn led on/off."""
+        return self.send("set_display", [display])
+
+    @command(
+        click.argument("ptc", type=bool),
+        default_output=format_output(
+            lambda ptc: "Turning on ptc" if ptc else "Turning off ptc"
+        ),
+    )
+    def set_ptc(self, ptc: bool):
+        """Turn ptc on/off."""
+        return self.send("set_ptc_on", [ptc])
+
+    @command(
+        click.argument("buzzer", type=bool),
+        default_output=format_output(
+            lambda buzzer: "Turning on buzzer" if buzzer else "Turning off buzzer"
+        ),
+    )
+    def set_buzzer(self, buzzer: bool):
+        """Set sound on/off."""
+        return self.send("set_sound", [buzzer])
+
+    @command(
+        click.argument("lock", type=bool),
+        default_output=format_output(
+            lambda lock: "Turning on child lock" if lock else "Turning off child lock"
+        ),
+    )
+    def set_child_lock(self, lock: bool):
+        """Set child lock on/off."""
+        return self.send("set_child_lock", [lock])
+
+    @command(default_output=format_output("Resetting dust filter"))
+    def reset_dust_filter(self):
+        """Resets filter lifetime of the dust filter."""
+        return self.send("set_filter_rate", [100])
+
+    @command(
+        click.argument("speed", type=int),
+        default_output=format_output("Setting favorite speed to {speed}"),
+    )
+    def set_favorite_speed(self, speed: int):
+        """Sets the fan speed in favorite mode."""
+        if speed < 0 or speed > 150:
+            raise AirFreshException("Invalid favorite speed: %s" % speed)
+
+        return self.send("set_favourite_speed", [speed])
+
+    @command()
+    def set_ptc_timer(self):
+        """
+        value = time.index + '-' +
+            time.hexSum + '-' +
+            time.startTime + '-' +
+            time.ptcTimer.endTime + '-' +
+            time.level + '-' +
+            time.status;
+        return self.send("set_ptc_timer", [value])
+        """
+        raise NotImplementedError()
+
+    @command()
+    def get_ptc_timer(self):
+        """Returns a list of PTC timers.
+
+        Response unknown.
+        """
+        return self.send("get_ptc_timer")
+
+    @command()
+    def get_timer(self):
+        """Response unknown."""
+        return self.send("get_timer")
 
 
-class AirFreshT2017(Device):
+class AirFreshT2017(AirFreshA1):
     """Main class representing the air fresh t2017."""
 
     def __init__(
@@ -275,38 +413,28 @@ class AirFreshT2017(Device):
     def status(self) -> AirFreshStatus:
         """Retrieve properties."""
 
-        properties = AVAILABLE_PROPERTIES[self.model]
-        values = self.get_properties(properties, max_properties=15)
-
-        return AirFreshStatus(defaultdict(lambda: None, zip(properties, values)))
-
-    @command(default_output=format_output("Powering on"))
-    def on(self):
-        """Power on."""
-        return self.send("set_power", [True])
-
-    @command(default_output=format_output("Powering off"))
-    def off(self):
-        """Power off."""
-        return self.send("set_power", [False])
+        return super().status()
 
     @command(
-        click.argument("mode", type=EnumType(OperationMode)),
-        default_output=format_output("Setting mode to '{mode.value}'"),
+        click.argument("speed", type=int),
+        default_output=format_output("Setting favorite speed to {speed}"),
     )
-    def set_mode(self, mode: OperationMode):
-        """Set mode."""
-        return self.send("set_mode", [mode.value])
+    def set_favorite_speed(self, speed: int):
+        """Sets the fan speed in favorite mode."""
+        if speed < 60 or speed > 300:
+            raise AirFreshException("Invalid favorite speed: %s" % speed)
 
-    @command(
-        click.argument("display", type=bool),
-        default_output=format_output(
-            lambda led: "Turning on display" if led else "Turning off display"
-        ),
-    )
-    def set_display(self, display: bool):
-        """Turn led on/off."""
-        return self.send("set_display", [display])
+        return self.send("set_favourite_speed", [speed])
+
+    @command(default_output=format_output("Resetting dust filter"))
+    def reset_dust_filter(self):
+        """Resets filter lifetime of the dust filter."""
+        return self.send("set_filter_reset", ["intermediate"])
+
+    @command(default_output=format_output("Resetting upper filter"))
+    def reset_upper_filter(self):
+        """Resets filter lifetime of the upper filter."""
+        return self.send("set_filter_reset", ["efficient"])
 
     @command(
         click.argument("orientation", type=EnumType(DisplayOrientation)),
@@ -316,16 +444,6 @@ class AirFreshT2017(Device):
         """Set display orientation."""
         return self.send("set_screen_direction", [orientation.value])
 
-    @command(
-        click.argument("ptc", type=bool),
-        default_output=format_output(
-            lambda ptc: "Turning on ptc" if ptc else "Turning off ptc"
-        ),
-    )
-    def set_ptc(self, ptc: bool):
-        """Turn ptc on/off."""
-        return self.send("set_ptc_on", [ptc])
-
     @command(
         click.argument("level", type=EnumType(PtcLevel)),
         default_output=format_output("Setting ptc level to '{level.value}'"),
@@ -333,67 +451,3 @@ class AirFreshT2017(Device):
     def set_ptc_level(self, level: PtcLevel):
         """Set PTC level."""
         return self.send("set_ptc_level", [level.value])
-
-    @command(
-        click.argument("buzzer", type=bool),
-        default_output=format_output(
-            lambda buzzer: "Turning on buzzer" if buzzer else "Turning off buzzer"
-        ),
-    )
-    def set_buzzer(self, buzzer: bool):
-        """Set sound on/off."""
-        return self.send("set_sound", [buzzer])
-
-    @command(
-        click.argument("lock", type=bool),
-        default_output=format_output(
-            lambda lock: "Turning on child lock" if lock else "Turning off child lock"
-        ),
-    )
-    def set_child_lock(self, lock: bool):
-        """Set child lock on/off."""
-        return self.send("set_child_lock", [lock])
-
-    @command(default_output=format_output("Resetting upper filter"))
-    def reset_upper_filter(self):
-        """Resets filter lifetime of the upper filter."""
-        return self.send("set_filter_reset", ["efficient"])
-
-    @command(default_output=format_output("Resetting dust filter"))
-    def reset_dust_filter(self):
-        """Resets filter lifetime of the dust filter."""
-        return self.send("set_filter_reset", ["intermediate"])
-
-    @command(
-        click.argument("speed", type=int),
-        default_output=format_output("Setting favorite speed to {speed}"),
-    )
-    def set_favorite_speed(self, speed: int):
-        """Storage register to enable extra features at the app."""
-        if speed < 60 or speed > 300:
-            raise AirFreshException("Invalid favorite speed: %s" % speed)
-
-        return self.send("set_favourite_speed", [speed])
-
-    @command()
-    def set_ptc_timer(self):
-        """
-        value = time.index + '-' +
-            time.hexSum + '-' +
-            time.startTime + '-' +
-            time.ptcTimer.endTime + '-' +
-            time.level + '-' +
-            time.status;
-        return self.send("set_ptc_timer", [value])
-        """
-        raise NotImplementedError()
-
-    @command()
-    def get_ptc_timer(self):
-        """Returns a list of PTC timers. Response unknown."""
-        return self.send("get_ptc_timer")
-
-    @command()
-    def get_timer(self):
-        """Response unknown."""
-        return self.send("get_timer")
